@@ -160,8 +160,11 @@ def column_clean(df, user_id, excl=None, semi_supervised='no', prioritize=None):
         elif 2 < df[c].nunique() <= 5:
             to_dummy.append(c)
             for k, v in df[c].value_counts().iteritems():
-                keep.append(k)
-                data_dict['categorical'][c] = {'kept': keep, 'others': others}
+                if 'other' not in k:
+                    keep.append(k)
+                    data_dict['categorical'][c] = {'kept': keep, 'others': others}
+                else: 
+                    others.append(k)
         # to_dummy, but changing values that take up less than 5% of values to "other"
         elif 5 < df[c].nunique() < df.shape[0]:
             for k, v in df[c].value_counts().iteritems():
